========
os-testr
========

A testr wrapper to provide functionality for OpenStack projects.

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/os-testr
* Source: http://git.openstack.org/cgit/openstack/os-testr
* Bugs: http://bugs.launchpad.net/os-testr

Features
--------

* ``ostestr``: a testr wrapper that uses subunit-trace for output and builds
  some helpful extra functionality around testr
* ``subunit-trace``: an output filter for a subunit stream which provides
  useful information about the run
* ``subunit2html``: generates a test results html page from a subunit stream
